@@ -8,9 +8,7 @@ def get(data={}):
 
 	If batch_key is included:
 	Retrieves a specific batch.
-
-	Args:
-		data (dict) contents:
+			batch_key (str) optional
 			limit (str) optional
 			offset (str) optional
 			openedlt (str) optional
