@@ -5,9 +5,6 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /batches/current/transactions
 	Retrieves transactin detail for the currently open batch.
-
-	Args:
-		data (dict) contents:
 			limit (str) optional
 			offset (str) optional
 			return_bin (str) optional
