@@ -5,9 +5,9 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /batches/{batch_key}/transactions
 	Retrieves transactin detail for a specific batch.
-
-	Args:
-		data (dict) contents:
+			limit (str) optional
+			offset (str) optional
+			return_bin (str) optional
 			batch_key (str) required
 
 	Returns:
