@@ -8,9 +8,7 @@ def get(data={}):
 
 	If custkey is included:
 	Retrieve a existing customer
-
-	Args:
-		data (dict) contents:
+			custkey (str) optional
 			limit (str) optional
 			offset (str) optional
 
@@ -48,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /customers/{custkey}
 	Delete a existing customer
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 
 	Returns:
@@ -66,9 +61,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /customers/{custkey}
 	Updates a existing customer
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			Also can contain all fields from CustomerRequest
 
