@@ -8,9 +8,7 @@ def get(data={}):
 
 	If billing_schedule_key is included:
 	Gets specific schedule from a customer
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
 			billing_schedule_key (str) optional
 
 	Returns:
@@ -31,9 +29,7 @@ def get(data={}):
 def post(data={}):
 	"""Calls /customers/{custkey}/billing_schedules
 	Add billing schedules to customer
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
 			CustomerSchedules (list) required
 
 	Returns:
@@ -50,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}
 	Delete a existing customer
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			billing_schedule_key (str) required
 
@@ -72,9 +65,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}
 	Update a customers billing schedule
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			billing_schedule_key (str) required
 			Also can contain all fields from CustomerSchedule
