@@ -8,9 +8,8 @@ def get(data={}):
 
 	If billing_rule_key is included:
 	Gets rules for a specific schedule from a customer
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
+			billing_schedule_key (str) required
 			billing_rule_key (str) optional
 
 	Returns:
@@ -34,9 +33,6 @@ def get(data={}):
 def delete(data={}):
 	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/{billing_rule_key}
 	Delete a existing customer billing rule
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			billing_schedule_key (str) required
 			billing_rule_key (str) required
@@ -60,9 +56,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/{billing_rule_key}
 	Gets rules for a specific schedule from a customer
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			billing_schedule_key (str) required
 			billing_rule_key (str) required
