@@ -5,9 +5,8 @@ from astropayments import run_call
 def delete(data={}):
 	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/bulk
 	Delete a existing customer billing rule
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
+			billing_schedule_key (str) required
 			Keys (list) required
 
 	Returns:
