@@ -5,9 +5,6 @@ from astropayments import run_call
 def delete(data={}):
 	"""Calls /customers/bulk
 	Deletes a list of customers.
-
-	Args:
-		data (dict) contents:
 			Keys (list) required
 
 	Returns:
