@@ -14,4 +14,4 @@ def post(data={}):
 	"""
 	params={}
 	path='/customers/enable'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
