@@ -8,9 +8,7 @@ def get(data={}):
 
 	If paymethod_key is included:
 	Delete a existing customer billing rule
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
 			paymethod_key (str) optional
 
 	Returns:
@@ -31,9 +29,7 @@ def get(data={}):
 def post(data={}):
 	"""Calls /customers/{custkey}/payment_methods
 	Add an array of new payment methods to an existing customer
-
-	Args:
-		data (dict) contents:
+			custkey (str) required
 			CustomerPaymentMethodRequests (list) required
 
 	Returns:
@@ -50,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /customers/{custkey}/payment_methods/{paymethod_key}
 	Delete a existing customer billing rule
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			paymethod_key (str) required
 
@@ -72,9 +65,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /customers/{custkey}/payment_methods/{paymethod_key}
 	Update an existing customer payment method
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 			paymethod_key (str) required
 			Also can contain all fields from CustomerPaymentMethodRequest
