@@ -5,9 +5,6 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /customers/{custkey}/transactions
 	Retrieve a existing customer
-
-	Args:
-		data (dict) contents:
 			custkey (str) required
 
 	Returns:
