@@ -8,9 +8,7 @@ def get(data={}):
 
 	If invoice_key is included:
 	Retreive details of a invoice in database
-
-	Args:
-		data (dict) contents:
+			invoice_key (str) optional
 			limit (str) optional
 			offset (str) optional
 
@@ -48,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /invoices/{invoice_key}
 	Delete a invoice from the database
-
-	Args:
-		data (dict) contents:
 			invoice_key (str) required
 
 	Returns:
@@ -66,9 +61,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /invoices/{invoice_key}
 	Update a invoice within the database
-
-	Args:
-		data (dict) contents:
 			invoice_key (str) required
 			Also can contain all fields from InvoiceRequest
 
