@@ -5,9 +5,6 @@ from astropayments import run_call
 def delete(data={}):
 	"""Calls /invoices/bulk
 	Get invoice defaults
-
-	Args:
-		data (dict) contents:
 			Keys (list) required
 
 	Returns:
