@@ -5,9 +5,8 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /invoices/{invoice_key}/payments
 	Retreive details of a invoice in database
-
-	Args:
-		data (dict) contents:
+			limit (str) optional
+			offset (str) optional
 			invoice_key (str) required
 
 	Returns:
