@@ -5,9 +5,6 @@ from astropayments import run_call
 def post(data={}):
 	"""Calls /invoices/{invoice_key}/send
 	Update a invoice within the database
-
-	Args:
-		data (dict) contents:
 			invoice_key (str) required
 
 	Returns:
