@@ -8,9 +8,7 @@ def get(data={}):
 
 	If devicekey is included:
 	Get a devices details
-
-	Args:
-		data (dict) contents:
+			devicekey (str) optional
 			limit (str) optional
 			offset (str) optional
 
@@ -48,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /paymentengine/devices/{devicekey}
 	Unregisters a device
-
-	Args:
-		data (dict) contents:
 			devicekey (str) required
 
 	Returns:
@@ -66,9 +61,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /paymentengine/devices/{devicekey}
 	Register a device
-
-	Args:
-		data (dict) contents:
 			devicekey (str) required
 			Also can contain all fields from DeviceRequest
 
