@@ -5,9 +5,6 @@ from astropayments import run_call
 def post(data={}):
 	"""Calls /paymentengine/devices/{devicekey}/kick
 	Kick a device offline
-
-	Args:
-		data (dict) contents:
 			devicekey (str) required
 
 	Returns:
