@@ -5,9 +5,6 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /paymentengine/devices/{devicekey}/settings
 	Get a devices settings
-
-	Args:
-		data (dict) contents:
 			devicekey (str) required
 
 	Returns:
@@ -23,9 +20,6 @@ def get(data={}):
 def put(data={}):
 	"""Calls /paymentengine/devices/{devicekey}/settings
 	Register a device
-
-	Args:
-		data (dict) contents:
 			devicekey (str) required
 			Also can contain all fields from DeviceSettings
 
