@@ -5,9 +5,6 @@ from astropayments import run_call
 def post(data={}):
 	"""Calls /paymentengine/payrequests/{requestkey}/confirm
 	Confirm the status of a transaction
-
-	Args:
-		data (dict) contents:
 			requestkey (str) required
 			Also can contain all fields from PayRequestConfirm
 
