@@ -8,9 +8,7 @@ def get(data={}):
 
 	If product_key is included:
 	Retreive details of a product in database
-
-	Args:
-		data (dict) contents:
+			product_key (str) optional
 			limit (str) optional
 			offset (str) optional
 
@@ -48,9 +46,6 @@ def post(data={}):
 def delete(data={}):
 	"""Calls /products/{product_key}
 	Delete a product from the database
-
-	Args:
-		data (dict) contents:
 			product_key (str) required
 
 	Returns:
@@ -66,9 +61,6 @@ def delete(data={}):
 def put(data={}):
 	"""Calls /products/{product_key}
 	Update a product within the database
-
-	Args:
-		data (dict) contents:
 			product_key (str) required
 			Also can contain all fields from ProductRequest
 
