@@ -8,9 +8,7 @@ def get(data={}):
 
 	If trankey is included:
 	Retrieve a specific transaction.
-
-	Args:
-		data (dict) contents:
+			trankey (str) optional
 			limit (str) optional
 			offset (str) optional
 			fuzzy (str) optional
