@@ -5,9 +5,6 @@ from astropayments import run_call
 def get(data={}):
 	"""Calls /transactions/{trankey}/receipts/{receipt_key}
 	Retrieve receipt for specific transaction.
-
-	Args:
-		data (dict) contents:
 			trankey (str) required
 			receipt_key (str) required
 
