@@ -5,9 +5,6 @@ from astropayments import run_call
 def post(data={}):
 	"""Calls /transactions/{trankey}/send
 	Email receipt for specific transaction.
-
-	Args:
-		data (dict) contents:
 			trankey (str) required
 			Also can contain all fields from SendReceiptRequest
 
